@@ -41,10 +41,10 @@ MetadataFilter::~MetadataFilter()
 
 void MetadataFilter::initMetaInformationSettings()
 {
-    const int currentVersion = 10; // increase version, if the blacklist of disabled
+    const int currentVersion = 11; // increase version, if the blacklist of disabled
     // properties should be updated
 
-    KConfig config("baloofileinformationrc", KConfig::NoGlobals);
+    KConfig config(QStringLiteral("baloofileinformationrc"), KConfig::NoGlobals);
     if (config.group("Misc").readEntry("version", 0) < currentVersion) {
         // The resource file is read the first time. Assure
         // that some meta information is disabled per default.
@@ -57,32 +57,14 @@ void MetadataFilter::initMetaInformationSettings()
             "comment",
             "contentSize",
             "depends",
-            "isPartOf",
             "lastModified",
             "created",
             "contentCreated",
             "mimeType",
-            "plainTextContent",
             "url",
-            "hasPart",
-            "averageBitrate",
             "channels",
             "fileName",
             "fileSize",
-            "Exif.Photo.ApertureValue",
-            "Exif.Photo.ExposureBiasValue",
-            "Exif.Photo.ExposureTime",
-            "Exif.Photo.Flash",
-            "Exif.Photo.FocalLength",
-            "Exif.Photo.FocalLengthIn35mmFilm",
-            "Exif.Photo.IsoSpeedRatings",
-            "Exif.Photo.MeteringMode",
-            "Exif.Photo.Orientation",
-            "Exif.Photo.WhiteBalance",
-            "Exif.Image.Make",
-            "Exif.Image.Model",
-            "Exif.Image.DateTime",
-            "Exif.Image.Orientation",
             "kfileitem#owner",
             "kfileitem#group",
             "kfileitem#permissions",
@@ -91,11 +73,18 @@ void MetadataFilter::initMetaInformationSettings()
             "replayGainTrackPeak",
             "replayGainTrackGain",
             "embeddedRating",
-            nullptr // mandatory last entry
+            "lyrics",
+            "photoWhiteBalance",
+            "photoMeteringMode",
+            "photoSharpness",
+            "photoSaturation",
+            "photoPixelXDimension",
+            "photoPixelYDimension",
         };
 
-        for (int i = 0; disabledProperties[i] != nullptr; ++i) {
-            settings.writeEntry(disabledProperties[i], false);
+
+        for (const auto property : disabledProperties) {
+            settings.writeEntry(property, false);
         }
 
         // mark the group as initialized
@@ -112,7 +101,7 @@ QVariantMap MetadataFilter::filter(const QVariantMap& data)
 
     //
     // Remove all items, that are marked as hidden in kmetainformationrc
-    KConfig config("baloofileinformationrc", KConfig::NoGlobals);
+    KConfig config(QStringLiteral("baloofileinformationrc"), KConfig::NoGlobals);
     KConfigGroup settings = config.group("Show");
     QVariantMap::iterator it = finalData.begin();
     while (it != finalData.end()) {
